(forward! reader)Advance by one non-line-break code point and return that code point.
Advance by one non-line-break code point and return that code point.
(forward-flow-run! reader quote single?)Advance over one contiguous non-blank quoted-scalar segment.
Advance over one contiguous non-blank quoted-scalar segment.
(forward-line! reader)Consume one YAML line break and return its normalized string value.
Consume one YAML line break and return its normalized string value.
(forward-line-run! reader)Advance over a non-line-break scalar/comment segment in one state update.
Advance over a non-line-break scalar/comment segment in one state update.
(forward-plain-run! reader flow?)Advance over one contiguous non-blank plain-scalar segment.
Advance over one contiguous non-blank plain-scalar segment.
(make-reader input)Create a reader over a YAML string. nil is treated as an empty string.
Create a reader over a YAML string. nil is treated as an empty string.
(peek-at reader offset)Return the code point offset characters ahead, or zero past EOF.
Return the code point `offset` characters ahead, or zero past EOF.
(peek-codepoint reader)Return the current code point, or zero at end of input.
Return the current code point, or zero at end of input.
(slice reader start end)Return the original input slice between two raw reader positions.
Return the original input slice between two raw reader positions.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |