(event->map e)Convert one internal event to the compatibility map consumed by YAMLStar.
Convert one internal event to the compatibility map consumed by YAMLStar.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |